# CellOrientationLinearElasticity

Small library to be used with netgen and ngsolve for simulation of cellular orientation in the context of linear elasticity. Archived at Zenodo (https://doi.org/10.5281/zenodo.6324986), development at github (https://github.com/tbgitoo/CellOrientationLinearElasticity)
